"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.QueryForm = void 0;
var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));
var _react = _interopRequireDefault(require("react"));
var _ui = require("@redux-devtools/ui");
var _createStylingFromTheme = require("../styles/createStylingFromTheme");
var _lodash = _interopRequireDefault(require("lodash.debounce"));
var _comparators = require("../utils/comparators");
var _filters = require("../utils/filters");
var _SortOrderButton = require("./SortOrderButton");
var _RegexIcon = require("./RegexIcon");
const selectId = 'rtk-query-comp-select';
const searchId = 'rtk-query-search-query';
const filterSelectId = 'rtk-query-search-query-select';
const searchPlaceholder = 'filter query by...';
const labels = {
  regexToggle: {
    info: 'Use regular expression search',
    error: 'Invalid regular expression provided'
  }
};
class QueryForm extends _react.default.PureComponent {
  constructor(props) {
    super(props);
    this.state = {
      searchValue: props.values.searchValue
    };
  }
  inputSearchRef = /*#__PURE__*/_react.default.createRef();
  handleSubmit = evt => {
    evt.preventDefault();
  };
  handleButtonGroupClick = isAsc => {
    this.props.onFormValuesChange({
      isAscendingQueryComparatorOrder: isAsc
    });
  };
  handleSelectComparatorChange = option => {
    if (typeof option?.value === 'string') {
      this.props.onFormValuesChange({
        queryComparator: option.value
      });
    }
  };
  handleSelectFilterChange = option => {
    if (typeof option?.value === 'string') {
      this.props.onFormValuesChange({
        queryFilter: option.value
      });
    }
  };
  handleRegexSearchClick = () => {
    this.props.onFormValuesChange({
      isRegexSearch: !this.props.values.isRegexSearch
    });
  };
  restoreCaretPosition = (start, end) => {
    window.requestAnimationFrame(() => {
      if (this.inputSearchRef.current) {
        this.inputSearchRef.current.selectionStart = start;
        this.inputSearchRef.current.selectionEnd = end;
      }
    });
  };
  invalidateSearchValueFromProps = (0, _lodash.default)(() => {
    this.props.onFormValuesChange({
      searchValue: this.state.searchValue
    });
  }, 150);
  handleSearchChange = evt => {
    const searchValue = evt.target.value.trim();
    this.setState({
      searchValue
    });
    this.invalidateSearchValueFromProps();
  };
  handleClearSearchClick = evt => {
    evt.preventDefault();
    if (this.state.searchValue) {
      this.setState({
        searchValue: ''
      });
      this.invalidateSearchValueFromProps();
    }
  };
  render() {
    const {
      searchQueryRegex,
      values: {
        isAscendingQueryComparatorOrder: isAsc,
        queryComparator,
        searchValue,
        queryFilter,
        isRegexSearch
      }
    } = this.props;
    const isRegexInvalid = isRegexSearch && searchValue.length > 0 && searchQueryRegex == null;
    const regexToggleType = isRegexInvalid ? 'error' : 'info';
    const regexToggleLabel = labels.regexToggle[regexToggleType];
    return /*#__PURE__*/_react.default.createElement(_createStylingFromTheme.StyleUtilsContext.Consumer, null, _ref => {
      let {
        styling,
        base16Theme
      } = _ref;
      return /*#__PURE__*/_react.default.createElement("form", (0, _extends2.default)({
        id: "rtk-query-monitor-query-selection-form",
        action: "#",
        onSubmit: this.handleSubmit
      }, styling('queryForm')), /*#__PURE__*/_react.default.createElement("div", styling('queryListHeader'), /*#__PURE__*/_react.default.createElement("label", (0, _extends2.default)({
        htmlFor: searchId
      }, styling('srOnly')), "filter query"), /*#__PURE__*/_react.default.createElement("div", styling('querySearch'), /*#__PURE__*/_react.default.createElement("input", {
        ref: this.inputSearchRef,
        type: "search",
        value: this.state.searchValue,
        onChange: this.handleSearchChange,
        placeholder: searchPlaceholder
      }), /*#__PURE__*/_react.default.createElement("button", (0, _extends2.default)({
        type: "reset",
        "aria-label": "clear search",
        "data-invisible": +(this.state.searchValue.length === 0) || undefined,
        onClick: this.handleClearSearchClick
      }, styling('closeButton'))), /*#__PURE__*/_react.default.createElement("button", (0, _extends2.default)({
        type: "button",
        "aria-label": regexToggleLabel,
        title: regexToggleLabel,
        "data-type": regexToggleType,
        "aria-pressed": isRegexSearch,
        onClick: this.handleRegexSearchClick
      }, styling('toggleButton')), /*#__PURE__*/_react.default.createElement(_RegexIcon.RegexIcon, null))), /*#__PURE__*/_react.default.createElement("label", (0, _extends2.default)({
        htmlFor: selectId
      }, styling('srOnly')), "filter by"), /*#__PURE__*/_react.default.createElement(_ui.Select, {
        id: filterSelectId,
        isSearchable: false,
        options: _filters.filterQueryOptions,
        theme: base16Theme,
        value: _filters.filterQueryOptions.find(opt => opt?.value === queryFilter),
        onChange: this.handleSelectFilterChange
      })), /*#__PURE__*/_react.default.createElement("div", styling('sortBySection'), /*#__PURE__*/_react.default.createElement("label", {
        htmlFor: selectId
      }, "Sort by"), /*#__PURE__*/_react.default.createElement(_ui.Select, {
        id: selectId,
        isSearchable: false,
        theme: base16Theme,
        value: _comparators.sortQueryOptions.find(opt => opt?.value === queryComparator),
        options: _comparators.sortQueryOptions,
        onChange: this.handleSelectComparatorChange
      }), /*#__PURE__*/_react.default.createElement(_SortOrderButton.SortOrderButton, {
        id: 'rtk-query-sort-order-button',
        isAsc: isAsc,
        onChange: this.handleButtonGroupClick
      })));
    });
  }
}
exports.QueryForm = QueryForm;