import _extends from "@babel/runtime/helpers/extends";
import { createSelector } from '@reduxjs/toolkit';
import React from 'react';
import { JSONTree } from 'react-json-tree';
import { DATA_TYPE_KEY } from '../monitor-config';
import { getJsonTreeTheme, StyleUtilsContext } from '../styles/createStylingFromTheme';
import { createTreeItemLabelRenderer, getItemString } from '../styles/tree';
import { identity } from '../utils/object';
export class TreeView extends React.PureComponent {
  static defaultProps = {
    hideRoot: true,
    shouldExpandNodeInitially: (keyPath, value, layer) => {
      return layer < 2;
    }
  };
  selectLabelRenderer = createSelector(identity, createTreeItemLabelRenderer);
  selectGetItemString = createSelector(identity, styling => (type, data) => getItemString(styling, type, data, DATA_TYPE_KEY, false));
  selectTheme = createSelector(identity, getJsonTreeTheme);
  constructor(props) {
    super(props);
  }
  render() {
    const {
      data,
      before,
      after,
      children,
      keyPath,
      shouldExpandNodeInitially,
      hideRoot,
      rootProps
    } = this.props;
    return /*#__PURE__*/React.createElement(StyleUtilsContext.Consumer, null, _ref => {
      let {
        styling,
        invertTheme,
        base16Theme
      } = _ref;
      return /*#__PURE__*/React.createElement("div", _extends({}, rootProps, styling('treeWrapper')), before, /*#__PURE__*/React.createElement(JSONTree, {
        keyPath: keyPath,
        shouldExpandNodeInitially: shouldExpandNodeInitially,
        data: data,
        labelRenderer: this.selectLabelRenderer(styling),
        theme: this.selectTheme(base16Theme),
        invertTheme: invertTheme,
        getItemString: this.selectGetItemString(styling),
        hideRoot: hideRoot
      }), after, children);
    });
  }
}