import _extends from "@babel/runtime/helpers/extends";
import React, { PureComponent, createRef } from 'react';
import { createInspectorSelectors, computeSelectorSource } from '../selectors';
import { changeQueryFormValues, selectedPreviewTab, selectQueryKey } from '../reducers';
import { QueryList } from '../components/QueryList';
import { QueryForm } from '../components/QueryForm';
import { QueryPreview } from './QueryPreview';
class RtkQueryInspector extends PureComponent {
  inspectorRef = /*#__PURE__*/createRef();
  isWideIntervalRef = null;
  constructor(props) {
    super(props);
    this.state = {
      isWideLayout: true,
      selectorsSource: computeSelectorSource(props, null)
    };
  }
  static wideLayout = 600;
  static getDerivedStateFromProps(props, state) {
    const selectorsSource = computeSelectorSource(props, state.selectorsSource);
    if (selectorsSource !== state.selectorsSource) {
      return {
        selectorsSource
      };
    }
    return null;
  }
  selectors = createInspectorSelectors();
  updateSizeMode = () => {
    if (this.inspectorRef.current) {
      const isWideLayout = this.inspectorRef.current.offsetWidth >= RtkQueryInspector.wideLayout;
      if (isWideLayout !== this.state.isWideLayout) {
        this.setState({
          isWideLayout
        });
      }
    }
  };
  componentDidMount() {
    this.updateSizeMode();
    this.isWideIntervalRef = setInterval(this.updateSizeMode, 300);
  }
  componentWillUnmount() {
    if (this.isWideIntervalRef) {
      clearTimeout(this.isWideIntervalRef);
    }
  }
  handleQueryFormValuesChange = values => {
    this.props.dispatch(changeQueryFormValues(values));
  };
  handleSelectQuery = queryInfo => {
    this.props.dispatch(selectQueryKey(queryInfo));
  };
  handleTabChange = tab => {
    this.props.dispatch(selectedPreviewTab(tab));
  };
  render() {
    const {
      selectorsSource,
      isWideLayout
    } = this.state;
    const {
      styleUtils: {
        styling
      }
    } = this.props;
    const allVisibleRtkResourceInfos = this.selectors.selectAllVisbileQueries(selectorsSource);
    const currentResInfo = this.selectors.selectCurrentQueryInfo(selectorsSource);
    const apiStates = this.selectors.selectApiStates(selectorsSource);
    const hasNoApi = apiStates == null;
    const searchQueryRegex = this.selectors.selectSearchQueryRegex(selectorsSource);
    return /*#__PURE__*/React.createElement("div", _extends({
      ref: this.inspectorRef,
      "data-wide-layout": +this.state.isWideLayout
    }, styling('inspector')), /*#__PURE__*/React.createElement("div", _extends({}, styling('querySectionWrapper'), {
      "data-wide-layout": +this.state.isWideLayout
    }), /*#__PURE__*/React.createElement(QueryForm, {
      searchQueryRegex: searchQueryRegex,
      values: selectorsSource.monitorState.queryForm.values,
      onFormValuesChange: this.handleQueryFormValuesChange
    }), /*#__PURE__*/React.createElement(QueryList, {
      onSelectQuery: this.handleSelectQuery,
      resInfos: allVisibleRtkResourceInfos,
      selectedQueryKey: selectorsSource.monitorState.selectedQueryKey
    })), /*#__PURE__*/React.createElement(QueryPreview, {
      selectorsSource: this.state.selectorsSource,
      selectors: this.selectors,
      resInfo: currentResInfo,
      selectedTab: selectorsSource.monitorState.selectedPreviewTab,
      onTabChange: this.handleTabChange,
      styling: styling,
      isWideLayout: isWideLayout,
      hasNoApis: hasNoApi
    }));
  }
}
export default RtkQueryInspector;